<?php
/**
 * Theme Dashboard.
 *
 * @package Paper Plane
 */

if ( ! class_exists( 'CSCO_Theme_Dashboard' ) ) {

	/**
	 * This class to activate your theme and open up new opportunities.
	 */
	class CSCO_Theme_Dashboard {

		/**
		 * The slug name to refer to this menu by.
		 *
		 * @var string $menu_slug The menu slug.
		 */
		public $menu_slug = 'csco-theme-dashboard';

		/**
		 * The importer menu slug.
		 *
		 * @var string $importer_menu_slug The importer menu slug.
		 */
		public $importer_menu_slug = 'csco-demo-content';

		/**
		 * The importer plugin slug.
		 *
		 * @var string $importer_plugin_slug The importer plugin slug.
		 */
		public $importer_plugin_slug = 'one-click-demo-import';

		/**
		 * The importer plugin path.
		 *
		 * @var string $importer_plugin_path The importer plugin path.
		 */
		public $importer_plugin_path = 'one-click-demo-import/one-click-demo-import.php';

		/**
		 * The purchase code.
		 *
		 * @var string $purchase_code The purchase code.
		 */
		public $purchase_code = null;

		/**
		 * The current theme slug.
		 *
		 * @var string $theme The current theme slug.
		 */
		public $theme;

		/**
		 * The current theme name.
		 *
		 * @var string $theme_name The current theme name.
		 */
		public $theme_name;

		/**
		 * The server domain.
		 *
		 * @var string $server The server domain.
		 */
		public $server;

		/**
		 * The message.
		 *
		 * @var string $msg The message.
		 */
		public $msg;

		/**
		 * Constructor.
		 */
		public function __construct() {
			$this->init();

			$this->trigger_subscribe();

			add_action( 'admin_menu', array( $this, 'register_options_page' ) );
			add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_scripts' ) );
			add_action( 'admin_notices', array( $this, 'welcome_panel' ) );
			add_action( 'wp_ajax_csco_install_importer_plugin', array( $this, 'install_importer_plugin' ) );
			add_action( 'wp_ajax_nopriv_csco_install_importer_plugin', array( $this, 'install_importer_plugin' ) );
			add_action( 'wp_ajax_csco_dismissed_handler', array( $this, 'dismissed_handler' ) );
		}

		/**
		 * Initialization
		 */
		public function init() {
			// Set current theme slug.
			$this->theme = get_template();
			// Set current theme name.
			$this->theme_name = $this->get_theme_data( 'Name' );
			// Set server url.
			$this->server = $this->get_theme_data( 'AuthorURI' );
		}

		/**
		 * Get data about the theme.
		 *
		 * @param mixed $name The name of param.
		 */
		public function get_theme_data( $name ) {
			$data = wp_get_theme( $this->theme );

			return $data->get( $name );
		}

		/**
		 * Register admin page
		 */
		public function register_options_page() {
			add_theme_page( esc_html__( 'Theme Dashboard', 'paper-plane' ), esc_html__( 'Theme Dashboard', 'paper-plane' ), 'manage_options', $this->menu_slug, array( $this, 'settings_page' ), 2 );
		}

		/**
		 * Return dashboard url
		 */
		public function get_dashboard_url() {
			return add_query_arg( 'page', $this->menu_slug, admin_url( 'themes.php' ) );
		}

		/**
		 * Get plugin status.
		 *
		 * @param string $plugin_path Plugin path.
		 */
		public function get_plugin_status( $plugin_path ) {
			if ( ! current_user_can( 'install_plugins' ) ) {
				return;
			}

			if ( ! file_exists( WP_PLUGIN_DIR . '/' . $plugin_path ) ) {
				return 'not_installed';
			} elseif ( in_array( $plugin_path, (array) get_option( 'active_plugins', array() ), true ) || is_plugin_active_for_network( $plugin_path ) ) {
				return 'active';
			} else {
				return 'inactive';
			}
		}

		/**
		 * Install a plugin.
		 *
		 * @param string $plugin_slug Plugin slug.
		 */
		public function install_plugin( $plugin_slug ) {
			if ( ! current_user_can( 'install_plugins' ) ) {
				return;
			}

			if ( ! function_exists( 'plugins_api' ) ) {
				require_once ABSPATH . 'wp-admin/includes/plugin-install.php';
			}
			if ( ! class_exists( 'WP_Upgrader' ) ) {
				require_once ABSPATH . 'wp-admin/includes/class-wp-upgrader.php';
			}

			if ( false === filter_var( $plugin_slug, FILTER_VALIDATE_URL ) ) {
				$api = plugins_api(
					'plugin_information',
					array(
						'slug'   => $plugin_slug,
						'fields' => array(
							'short_description' => false,
							'sections'          => false,
							'requires'          => false,
							'rating'            => false,
							'ratings'           => false,
							'downloaded'        => false,
							'last_updated'      => false,
							'added'             => false,
							'tags'              => false,
							'compatibility'     => false,
							'homepage'          => false,
							'donate_link'       => false,
						),
					)
				);

				$download_link = $api->download_link;
			} else {
				$download_link = $plugin_slug;
			}

			// Use AJAX upgrader skin instead of plugin installer skin.
			// ref: function wp_ajax_install_plugin().
			$upgrader = new Plugin_Upgrader( new WP_Ajax_Upgrader_Skin() );

			$install = $upgrader->install( $download_link );

			if ( false === $install ) {
				return false;
			} else {
				return true;
			}
		}

		/**
		 * Activate a plugin.
		 *
		 * @param string $plugin_path Plugin path.
		 */
		public function activate_plugin( $plugin_path ) {

			if ( ! current_user_can( 'install_plugins' ) ) {
				return false;
			}

			$activate = activate_plugin( $plugin_path, '', false, true );

			if ( is_wp_error( $activate ) ) {
				return false;
			} else {
				return true;
			}
		}

		/**
		 * Install importer plugin.
		 */
		public function install_importer_plugin() {
			if ( ! current_user_can( 'install_plugins' ) ) {
				wp_send_json_error( esc_html__( 'Insufficient permissions to install the plugin.', 'paper-plane' ) );
				wp_die();
			}

			if ( 'not_installed' === $this->get_plugin_status( $this->importer_plugin_path ) ) {

				$this->install_plugin( $this->importer_plugin_slug );

				$this->activate_plugin( $this->importer_plugin_path );

			} elseif ( 'inactive' === $this->get_plugin_status( $this->importer_plugin_path ) ) {

				$this->activate_plugin( $this->importer_plugin_path );
			}

			if ( 'active' === $this->get_plugin_status( $this->importer_plugin_path ) ) {
				wp_send_json_success();
			}

			wp_send_json_error( esc_html__( 'Failed to initialize or activate importer plugin.', 'paper-plane' ) );

			wp_die();
		}

		/**
		 * Set message.
		 *
		 * @param string $text The text of message.
		 * @param string $type The type of message.
		 */
		public function set_message( $text, $type = 'error' ) {
			ob_start();
			?>
			<div class="notice notice-<?php echo esc_attr( $type ); ?>">
				<p><?php echo wp_kses( $text, 'csco' ); ?></p>
			</div>
			<?php
			return ob_get_clean();
		}

		/**
		 * Get option name with subscribe.
		 */
		public function get_subscribe() {
			return get_option( 'csco_subscribe' );
		}

		/**
		 * Update subscribe.
		 */
		public function update_subscribe() {
			return update_option( 'csco_subscribe', true );
		}

		/**
		 * Build admin page
		 */
		public function settings_page() {

			wp_verify_nonce( null );

			if ( ! current_user_can( 'manage_options' ) ) {
				wp_die( esc_html__( 'You do not have sufficient rights to view this page.', 'paper-plane' ) );
			}
			?>
				<div class="wrap">
					<h1><?php echo esc_html( get_admin_page_title() ); ?></h1>
					<?php
					// Message output.
					if ( $this->msg ) {
						echo wp_kses( $this->msg, 'csco' );
					}

					// Get demo import url.
					$import_url = admin_url( 'themes.php?page=csco-demo-content' );

					if ( class_exists( 'CSCO_Demos_Core' ) ) {
						$import_url = admin_url( 'customize.php?autofocus[section]=csco-section' );
					}

					// Get TGM_Plugin_Activation.
					$tgmpa = TGM_Plugin_Activation::get_instance();

					// Is active all plugins ?
					$is_active_plugins = true;

					foreach ( $tgmpa->plugins as $plugin ) {
						if ( 'active' !== $this->get_plugin_status( $plugin['file_path'] ) ) {
							$is_active_plugins = false;
						}
					}
					?>

					<div class="welcome-panel csco-welcome-panel">

						<div class="welcome-panel-content">

							<div class="welcome-panel-header">
								<h2>
									<?php
									/* translators: %s: Theme Name. */
									echo esc_html( sprintf( __( 'Welcome to %s!', 'paper-plane' ), $this->theme_name ) );
									?>
								</h2>
								<p><?php esc_html_e( 'We’ve assembled some links to get you started:', 'paper-plane' ); ?></p>
							</div>

							<div class="welcome-panel-column-container">

								<div class="welcome-panel-column">

									<h3><?php esc_html_e( 'Install Recommended Plugins', 'paper-plane' ); ?></h3>

									<?php if ( $is_active_plugins ) { ?>
										<div class="button button-primary button-hero button-plugins button-disabled">
											<?php esc_html_e( 'Install Plugins', 'paper-plane' ); ?>
										</div>

										<p><?php esc_html_e( 'All recommended plugins have been successfully installed and activated.', 'paper-plane' ); ?></p>
									<?php } else { ?>

										<a class="button button-primary button-hero button-plugins" href="<?php echo esc_url( $tgmpa->get_tgmpa_url() ); ?>">
											<?php esc_html_e( 'Install Plugins', 'paper-plane' ); ?>
										</a>
									<?php } ?>

								</div>

								<div class="welcome-panel-column">

									<h3><?php esc_html_e( 'Import a Demo', 'paper-plane' ); ?></h3>

									<?php
									if ( 'active' === $this->get_plugin_status( $this->importer_plugin_path ) ) {
										$target = 'active';
									}
									?>

									<a href="<?php echo esc_url( add_query_arg( 'page', $this->importer_menu_slug, admin_url( 'themes.php' ) ) ); ?>" data-target="<?php echo esc_attr( $target ); ?>" class="csco-import-demo button button-primary button-hero button-demo">
										<?php esc_html_e( 'Import a Demo', 'paper-plane' ); ?>
									</a>

									<?php if ( 'active' !== $this->get_plugin_status( $this->importer_plugin_path ) ) { ?>
										<p>
											<?php esc_html_e( 'Clicking “Import a Demo” button will install and activate the demo importer plugin.', 'paper-plane' ); ?>
										</p>
									<?php } ?>

								</div>

								<div class="welcome-panel-column">

									<h3><?php esc_html_e( 'Next Steps', 'paper-plane' ); ?></h3>
									<ul>
										<li>
											<a href="<?php echo esc_url( home_url( '/' ) ); ?>" class="welcome-icon welcome-view-site"><?php esc_html_e( 'View your site', 'paper-plane' ); ?></a>
										</li>
										<li>
										<?php
											/* translators: %s: URL to Themes panel in Customizer or Themes screen. */
											echo wp_kses( sprintf( '<a href="' . esc_url( admin_url( 'customize.php' ) ) . '" class="welcome-icon dashicons-admin-appearance">' . __( 'Customize your site', 'paper-plane' ) . '</a>' ), 'csco' );
										?>
										</li>
										<li>
											<a href="<?php echo esc_url( admin_url( 'nav-menus.php' ) ); ?>" class="welcome-icon welcome-menus"><?php esc_html_e( 'Manage menus', 'paper-plane' ); ?></a>
										</li>

										<?php if ( 'active' === $this->get_plugin_status( 'envato-market/envato-market.php' ) ) { ?>
											<li>
												<a href="<?php echo esc_url( add_query_arg( 'page', 'envato-market', admin_url( 'admin.php' ) ) ); ?>" class="welcome-icon dashicons-update-alt"><?php esc_html_e( 'Enable automatic theme updates', 'paper-plane' ); ?></a>
											</li>
										<?php } ?>

										<li>
											<a href="<?php echo esc_url( 'https://codesupply.co/documentation/' . $this->theme ); ?>" class="welcome-icon welcome-learn-more" target="_blank"><?php esc_html_e( 'View theme documentation', 'paper-plane' ); ?></a>
										</li>
									</ul>

								</div>

							</div>

						</div>

					</div>

					<?php if ( ! $this->get_subscribe() ) { ?>
						<div id="poststuff">
							<div class="postbox">

								<h2 class="hndle"><span><?php esc_html_e( 'Updates', 'paper-plane' ); ?></span></h2>

								<div class="inside">
									<p style="font-size: 14px;margin-bottom: 0;"><?php esc_html_e( 'We set a special price for all new themes for just a few days. Get notified of all introductory, flash and seasonal sales by signing up to our updates.', 'paper-plane' ); ?></p>

									<form method="post" style="max-width:864px;">
										<?php wp_nonce_field(); ?>

										<table class="form-table">
											<!-- Email Address -->
											<tr>
												<th scope="row"><?php esc_html_e( 'Email Address', 'paper-plane' ); ?></label></th>
												<td>
													<input class="regular-text" type="text" name="email" value="<?php echo esc_attr( get_bloginfo( 'admin_email' ) ); ?>">
												</td>
											</tr>
											<!-- Updates -->
											<tr>
												<th scope="row"></th>
												<td>
												<div style="display:flex;">
													<input style="margin: 10px 15px 0 0;" id="newsletter" name="newsletter" type="checkbox" value="1">

													<label for="newsletter">
														<p><?php esc_html_e( 'By checking this box you agree to our', 'paper-plane' ); ?> <a href="https://codesupply.co/terms-and-conditions/" target="_blank"><?php esc_html_e( 'Terms and Conditions', 'paper-plane' ); ?></a> <?php esc_html_e( 'and', 'paper-plane' ); ?> <a href="https://codesupply.co/privacy-policy/" target="_blank"><?php esc_html_e( 'Privacy Policy', 'paper-plane' ); ?></a>.</p>

														<p class="description"><?php esc_html_e( 'You may opt-out any time by clicking the unsubscribe link in the footer of any email you receice from us, or by contacting us at', 'paper-plane' ); ?> <a target="_blank" href="mailto:support@codesupply.co"><?php esc_html_e( 'support@codesupply.co', 'paper-plane' ); ?></a>.</p>
													</label>
													</div>
												</td>
											</tr>
											<!-- Submitbox -->
											<tr>
												<th scope="row"></th>
												<td>
													<button name="action" value="subscribe" type="submit" class="button button-primary button-large" id="publish"><?php esc_html_e( 'Subscribe', 'paper-plane' ); ?></button>
												</td>
											</tr>
										</table>
									</form>
								</div>
							</div>
						</div>
					<?php } ?>
				</div>
			<?php
		}

		/**
		 * Welocome panel
		 */
		public function welcome_panel() {
			global $pagenow;

			$screen = get_current_screen();

			if ( ! isset( $_GET['activated'] ) ) {
				return;
			}

			if ( 'themes.php' === $pagenow && 'themes' === $screen->base ) {
				?>
				<div class="notice notice-info is-dismissible" style="border: none; margin: 0; padding: 0;">
					<button type="button" class="notice-dismiss"></button>

					<div class="welcome-panel csco-welcome-panel" style="padding-bottom: 14px">
						<div class="welcome-panel-content">

							<div class="welcome-panel-header">
								<h2>
									<?php
									/* translators: %s: Theme Name. */
									echo esc_html( sprintf( __( 'Thank you for installing %s!', 'paper-plane' ), $this->theme_name ) );
									?>
								</h2>
								<p>
									<?php
										/* translators: %s: Theme Name. */
										echo esc_html( sprintf( __( 'Please visit the theme dashboard for more info about %s features.', 'paper-plane' ), $this->theme_name ) );
									?>
								</p>
								<p>
									<a class="button button-hero" href="<?php echo esc_url( $this->get_dashboard_url() ); ?>">
										<?php esc_html_e( 'Theme Dashboard', 'paper-plane' ); ?>
									</a>
								</p>
							</div>

						</div>
					</div>
				</div>
				<?php
			}
		}

		/**
		 * Trigger subscribe.
		 */
		public function trigger_subscribe() {
			if ( ! isset( $_POST['_wpnonce'] ) || ! wp_verify_nonce( $_POST['_wpnonce'] ) ) { // Input var ok; sanitization ok.
				return;
			}

			$email = null;

			// Get action.
			if ( ! isset( $_POST['action'] ) ) { // Input var ok.
				return;
			}

			$action = sanitize_text_field( $_POST['action'] ); // Input var ok; sanitization ok.

			// Get email.
			if ( 'subscribe' === $action ) {
				if ( isset( $_POST['email'] ) && $_POST['email'] ) { // Input var ok; sanitization ok.
					$email = sanitize_email( wp_unslash( $_POST['email'] ) ); // Input var ok.
				} else {
					$this->msg = $this->set_message( esc_html__( 'Email address is considered invalid.', 'paper-plane' ) );
					return;
				}

				if ( ! isset( $_POST['newsletter'] ) ) { // Input var ok; sanitization ok.
					$this->msg = $this->set_message( esc_html__( 'Please agree to our terms and conditions.', 'paper-plane' ) );
					return;
				}

				// Get url server.
				$remote_url = sprintf( '%s/wp-json/csco/v1/simple-subscribe', $this->server );

				// Remote query.
				$response = wp_remote_post(
					$remote_url,
					array(
						'timeout'     => 45,
						'redirection' => 5,
						'httpversion' => '1.0',
						'blocking'    => true,
						'headers'     => array(),
						'body'        => array(
							'action' => $action,
							'email'  => $email,
						),
						'cookies'     => array(),
					)
				);

				if ( is_wp_error( $response ) ) {
					$this->msg = $this->set_message( esc_html__( 'No connection to the server, try another time, or contact support.', 'paper-plane' ) );
					return;
				}

				// Retrieve data.
				$data = wp_remote_retrieve_body( $response );

				// JSON Decode.
				$data = json_decode( $data, true );

				// Subscribe.
				if ( isset( $data['data']['subscribe'] ) && $data['data']['subscribe'] ) {

					$this->update_subscribe();

					$this->msg = $this->set_message( esc_html__( 'Successfully subscribed.', 'paper-plane' ), 'success' );

				} elseif ( ! isset( $data['message'] ) ) {
					$this->msg = $this->set_message( esc_html__( 'Could not receive data from the server, try another time, or contact support.', 'paper-plane' ) );
				} else {
					$this->msg = $data['message'];
				}
			}
		}

		/**
		 * Dismissed handler
		 */
		public function dismissed_handler() {
			wp_verify_nonce( null );

			if ( isset( $_POST['notice'] ) ) { // Input var ok; sanitization ok.
				set_transient( sanitize_text_field( wp_unslash( $_POST['notice'] ) ), true, 90 * DAY_IN_SECONDS ); // Input var ok.
			}
		}

		/**
		 *  Enqunue Scripts
		 *
		 * @param string $page Current page.
		 */
		public function enqueue_scripts( $page ) {
			wp_enqueue_script( 'jquery' );

			ob_start();
			?>
			<script>
				jQuery(function($) {
					$( document ).on( 'click', '.csco-notice .notice-dismiss', function () {
						jQuery.post( 'ajax_url', {
							action: 'csco_dismissed_handler',
							notice: $( this ).closest( '.csco-notice' ).data( 'notice' ),
						});
					} );

					$( document ).on( 'click', '.csco-import-demo', function( e ) {
						if ( 'redirect' === $( this ).data( 'target' ) && ! $( this ).hasClass( 'init' ) ) {

							var $href = $( this ).attr( 'href' );

							var $caption = $( this ).html();

							var $self = this;

							var data = {
								'action' : 'csco_install_importer_plugin',
							};

							$( $self ).addClass( 'init' );

							$( $self ).siblings( '.csco-import-warning' ).remove();

							$( $self ).html( 'Installing…' );

							// Send Request.
							$.post( 'ajax_url', data, function( responsive ) {

								if ( responsive.success ) {

									$( $self ).html( '<i class="dashicons dashicons-saved"></i> Activated' );

									setTimeout( function() {

										$( $self ).html( 'Redirecting…' );

										$( $self ).siblings( '.csco-import-warning' ).remove();

										setTimeout( function() {

											window.location = $href;

										}, 1000 );

									}, 500 );

								} else if ( responsive.data ) {
									$( $self ).html( $caption );

									$( $self ).after( `<div class="csco-import-warning"><i>${responsive.data}</i></div>` );

									$( $self ).removeClass( 'init' );
								} else {
									$( $self ).html( $caption );

									$( $self ).after( `<div class="csco-import-warning"><i>Something went wrong, contact support.</i></div>` );

									$( $self ).removeClass( 'init' );
								}

							} ).fail( function( xhr, textStatus, e ) {
								$( $self ).html( $caption );

								$( $self ).after( `<div class="csco-import-warning"><i>Something went wrong, contact support.</i></div>` );

								$( $self ).removeClass( 'init' );
							} );

							e.preventDefault();
						}
					} );
				});
			</script>
			<?php
			$script = str_replace( 'ajax_url', admin_url( 'admin-ajax.php' ), ob_get_clean() );

			wp_add_inline_script( 'jquery', str_replace( array( '<script>', '</script>' ), '', $script ) );
		}
	}

	new CSCO_Theme_Dashboard();
}
