<?php
/**
 * These functions are used to load template parts (partials) or actions when used within action hooks,
 * and they probably should never be updated or modified.
 *
 * @package Paper Plane
 */

if ( ! function_exists( 'csco_singular_post_type_before' ) ) {
	/**
	 * Add Before Singular Hooks for specific post type.
	 */
	function csco_singular_post_type_before() {
		if ( 'post' === get_post_type() ) {
			do_action( 'csco_post_content_before' );
		}
		if ( 'page' === get_post_type() ) {
			do_action( 'csco_page_content_before' );
		}
	}
}

if ( ! function_exists( 'csco_singular_post_type_after' ) ) {
	/**
	 * Add After Singular Hooks for specific post type.
	 */
	function csco_singular_post_type_after() {
		if ( 'post' === get_post_type() ) {
			do_action( 'csco_post_content_after' );
		}
		if ( 'page' === get_post_type() ) {
			do_action( 'csco_page_content_after' );
		}
	}
}

if ( ! function_exists( 'csco_fullscreen_menu' ) ) {
	/**
	 * Fullscreen Menu
	 */
	function csco_fullscreen_menu() {
		get_template_part( 'template-parts/fullscreen-menu' );
	}
}

if ( ! function_exists( 'csco_site_scheme' ) ) {
	/**
	 * Site Scheme
	 */
	function csco_site_scheme() {
		$data = csco_site_scheme_data();

		call_user_func( 'printf', '%s', "data-scheme='{$data['scheme']}' data-site-scheme='{$data['site_scheme']}'" );
	}
}

if ( ! function_exists( 'csco_post_attr' ) ) {
	/**
	 * Site Scheme
	 */
	function csco_post_attr() {
		$text_color = get_post_meta( get_the_ID(), 'csco_post_text_color', true );
		if ( ! $text_color ) {
			$text_color = '#ffffff';
		}
		call_user_func( 'printf', '%s', ' data-color="' . esc_attr( $text_color ) . '" style="--cs-entry-color:' . esc_attr( $text_color ) . '"');
	}
}

if ( ! function_exists( 'csco_site_content_attr' ) ) {
	/**
	 * Site Content Attributes
	 */
	function csco_site_content_attr() {
		if ( is_singular( 'post' ) ) {
			return;
		}

		$color      = '#000000';
		$color_dark = '#ffffff';

		call_user_func( 'printf', '%s', ' data-color="' . esc_attr( $color ) . '" data-color-dark="' . esc_attr( $color_dark ) . '"');
	}
}

if ( ! function_exists( 'csco_post_container_attr' ) ) {
	/**
	 * Post Container Attributes
	 */
	function csco_post_container_attr() {
		if ( ! is_singular( 'post' ) ) {
			return;
		}
		$color      = '#000000';
		$color_dark = '#ffffff';

		call_user_func( 'printf', '%s', ' data-color="' . esc_attr( $color ) . '" data-color-dark="' . esc_attr( $color_dark ) . '"');
	}
}

if ( ! function_exists( 'csco_site_search' ) ) {
	/**
	 * Site Search
	 */
	function csco_site_search() {
		if ( ! get_theme_mod( 'header_search_button', true ) ) {
			return;
		}
		get_template_part( 'template-parts/site-search' );
	}
}

if ( ! function_exists( 'csco_site_nav_mobile' ) ) {
	/**
	 * Site Nav Mobile
	 */
	function csco_site_nav_mobile() {
		get_template_part( 'template-parts/site-nav-mobile' );
	}
}

if ( ! function_exists( 'csco_breadcrumbs' ) ) {
	/**
	 * SEO Breadcrumbs
	 */
	function csco_breadcrumbs() {
		if ( ! apply_filters( 'csco_breadcrumbs', true ) ) {
			return;
		}

		if ( is_front_page() || is_category() ) {
			return;
		}

		if ( csco_doing_request() ) {
			return;
		}

		if ( ! function_exists( 'yoast_breadcrumb' ) ) {
			return;
		}

		ob_start();

		yoast_breadcrumb( '<div class="cs-breadcrumbs" id="breadcrumbs">', '</div>' );

		// Check the number of levels in breadcrumbs.
		preg_match_all( '/<\/a>/', ob_get_contents(), $matches );

		if ( ! isset( $matches[0] ) || count( $matches[0] ) <= 1 ) {
			ob_end_clean();

			return;
		}

		return ob_end_flush();
	}
}

if ( ! function_exists( 'csco_page_header' ) ) {
	/**
	 * Page Header
	 */
	function csco_page_header() {
		if ( ! ( is_archive() || is_search() || is_404() ) ) {
			return;
		}
		get_template_part( 'template-parts/page-header' );
	}
}

if ( ! function_exists( 'csco_page_pagination' ) ) {
	/**
	 * Post Pagination
	 */
	function csco_page_pagination() {
		if ( ! is_singular() ) {
			return;
		}

		do_action( 'csco_pagination_before' );

		wp_link_pages(
			array(
				'before'           => '<div class="navigation pagination"><div class="nav-links">',
				'after'            => '</div></div>',
				'link_before'      => '<span class="page-number">',
				'link_after'       => '</span>',
				'next_or_number'   => 'next_and_number',
				'separator'        => ' ',
				'nextpagelink'     => esc_html__( 'Next page', 'paper-plane' ),
				'previouspagelink' => esc_html__( 'Previous page', 'paper-plane' ),
			)
		);

		do_action( 'csco_pagination_after' );
	}
}

if ( ! function_exists( 'csco_meet_team' ) ) {
	/**
	 * Meet Team
	 */
	function csco_meet_team() {
		if ( is_page_template( 'template-meet-team.php' ) ) {
			get_template_part( 'template-parts/meet-team' );
		}
	}
}

if ( ! function_exists( 'csco_entry_metabar' ) ) {
	/**
	 * Entry Metabar
	 */
	function csco_entry_metabar() {
		if ( ! is_singular( 'post' ) ) {
			return;
		}
		if ( ! csco_is_metabar() ) {
			return;
		}
		?>

		<div class="cs-entry__metabar">
			<?php
			if ( true === get_theme_mod( 'post_author', false ) ) {
				get_template_part( 'template-parts/entry/entry-author' );
			}
			?>
			<?php if ( csco_is_metabar_share() ) { ?>
				<div class="cs-entry__metabar-inner">
					<?php powerkit_share_buttons_location( 'metabar-post' ); ?>
				</div>
			<?php } ?>
		</div>
		<?php
	}
}

if ( ! function_exists( 'csco_entry_tags' ) ) {
	/**
	 * Entry Tags
	 */
	function csco_entry_tags() {
		if ( ! is_singular( 'post' ) ) {
			return;
		}
		if ( false === get_theme_mod( 'post_tags', true ) ) {
			return;
		}

		the_tags( '<div class="cs-entry__tags"><ul><li>', '</li><li>', '</li></ul></div>' );
	}
}

if ( ! function_exists( 'csco_entry_share_button' ) ) {
	/**
	 * Entry Share
	 */
	function csco_entry_share_button() {
		if ( ! is_singular( 'post' ) ) {
			return;
		}
		if ( csco_powerkit_module_enabled( 'share_buttons' ) ) {
			powerkit_share_buttons_location( 'after-post' );
		}
	}
}

if ( ! function_exists( 'csco_entry_footer' ) ) {
	/**
	 * Entry Footer
	 */
	function csco_entry_footer() {
		if ( ! csco_is_entry_footer() ) {
			return;
		}
		get_template_part( 'template-parts/entry/entry-footer' );
	}
}

if ( ! function_exists( 'csco_entry_comments' ) ) {
	/**
	 * Entry Comments
	 */
	function csco_entry_comments() {
		if ( post_password_required() ) {
			return;
		}

		if ( comments_open() || get_comments_number() ) {
			comments_template();
		}
	}
}

if ( ! function_exists( 'csco_entry_comments_button' ) ) {
	/**
	 * Entry Comments
	 */
	function csco_entry_comments_button() {
		if ( post_password_required() ) {
			return;
		}

		if ( comments_open() || get_comments_number() ) {
			get_template_part( 'template-parts/entry/entry-comments-button' );
		}
	}
}

if ( ! function_exists( 'csco_entry_subscribe' ) ) {
	/**
	 * Post Subscribe
	 */
	function csco_entry_subscribe() {
		if ( ! is_singular( 'post' ) ) {
			return;
		}
		if ( false === get_theme_mod( 'post_subscribe', false ) ) {
			return;
		}

		if ( csco_powerkit_module_enabled( 'opt_in_forms' ) ) {
			get_template_part( 'template-parts/entry/entry-subscribe' );
		}
	}
}

if ( ! function_exists( 'csco_entry_related' ) ) {
	/**
	 * Entry Related
	 */
	function csco_entry_related() {
		if ( ! is_singular( 'post' ) ) {
			return;
		}
		if ( csco_doing_request() ) {
			return;
		}
		if ( false === get_theme_mod( 'related', false ) ) {
			return;
		}
		get_template_part( 'template-parts/entry/entry-related' );
	}
}
